<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Σφάλμα έκφρασης</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Σκοτεινό θεμα</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Απλή λειτουργία</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Επιστημονική λειτουργία</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Αριθμομηχανή Deepin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Η αριθμομηχανή του Deepin είναι μία απλή και εύκολη στην χρήση αριθμομηχανή. Υποστηρίζει πρόσθεση, αφαίρεση, πολλαπλασιασμό και διαίρεση. </translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Σφάλμα έκφρασης</translation>
    </message>
</context>
</TS>